# pydantic-ai-visual

[![Release](https://img.shields.io/github/v/release/wh1isper/pydantic-ai-visual)](https://img.shields.io/github/v/release/wh1isper/pydantic-ai-visual)
[![Build status](https://img.shields.io/github/actions/workflow/status/wh1isper/pydantic-ai-visual/main.yml?branch=main)](https://github.com/wh1isper/pydantic-ai-visual/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/wh1isper/pydantic-ai-visual/branch/main/graph/badge.svg)](https://codecov.io/gh/wh1isper/pydantic-ai-visual)
[![Commit activity](https://img.shields.io/github/commit-activity/m/wh1isper/pydantic-ai-visual)](https://img.shields.io/github/commit-activity/m/wh1isper/pydantic-ai-visual)
[![License](https://img.shields.io/github/license/wh1isper/pydantic-ai-visual)](https://img.shields.io/github/license/wh1isper/pydantic-ai-visual)

pydantic-ai messages visualization
